#!/bin/bash
#
# I've occasionally had problems with .shtml inclusion for the header
# and footer.  Since there's not any processing going on in those
# files, they can be straight .html instead.  This script makes the
# necessary adjustments.
#
# In one installation, the errors raised in the apache logs were
#   unable to include potential exec
# since the SSI handler was attempting to parse the header/footer as
# well.  I'm not sure why it had a problem with that, but changing
# them to .html files means the SSI handler will no longer try to
# parse them and you avoid the problem.
#
#
# Usage: ./html-includes.sh

set -e # exit immediately on failed command
set -o pipefail # pipes fail if any stage fails
set -v # verbose, echo commands to stdout


for FILE in $(ls html/shared/ | grep '.shtml$'); do
    mv -v "html/shared/${FILE}" "html/shared/${FILE/shtml/html}"
    for CALLER in html/*.shtml; do
	# correct links for callers
	sed -i "s/shared\/$FILE/shared\/${FILE/shtml/html}/" "$CALLER"
    done
done

